@@ -7,7 +7,7 @@
 /*	#include <rcpt_print.h>
 /*
 /*	int     rcpt_print(print_fn, stream, flags, ptr)
-/*	ATTR_PRINT_MASTER_FN print_fn;
+/*	ATTR_PRINT_COMMON_FN print_fn;
 /*	VSTREAM *stream;
 /*	int	flags;
 /*	void	*ptr;
@@ -30,6 +30,11 @@
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
+/*
+/*	Wietse Venema
+/*	Google, Inc.
+/*	111 8th Avenue
+/*	New York, NY 10011, USA
 /*--*/
 
 /* System library. */
@@ -48,7 +53,7 @@
 
 /* rcpt_print - write recipient to stream */
 
-int     rcpt_print(ATTR_PRINT_MASTER_FN print_fn, VSTREAM *fp,
+int     rcpt_print(ATTR_PRINT_COMMON_FN print_fn, VSTREAM *fp,
 		           int flags, void *ptr)
 {
     RECIPIENT *rcpt = (RECIPIENT *) ptr;
